@@ -6,6 +6,6 @@ except Exception:
     no_setproctitle = True
 
 
-def setproctitle(ps_name) -> None:
+def setproctitle(ps_name: str) -> None:
     if no_setproctitle is False:
         pysetproctitle.setproctitle(ps_name)
