@@ -1,6 +1,6 @@
 from unittest import TestCase
 
-from chia.types.blockchain_format.program import Program, SerializedProgram
+from chia.types.blockchain_format.program import Program, SerializedProgram, INFINITE_COST
 from chia.wallet.puzzles.load_clvm import load_clvm
 
 SHA256TREE_MOD = load_clvm("sha256tree_module.clvm")
@@ -16,7 +16,7 @@ class TestSerializedProgram(TestCase):
     def test_program_execution(self):
         p_result = SHA256TREE_MOD.run(SHA256TREE_MOD)
         sp = SerializedProgram.from_bytes(bytes(SHA256TREE_MOD))
-        cost, sp_result = sp.run_with_cost(sp)
+        cost, sp_result = sp.run_with_cost(INFINITE_COST, sp)
         self.assertEqual(p_result, sp_result)
 
     def test_serialization(self):
