@@ -7,14 +7,14 @@ from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import hashes, serialization
 
-from src.protocols.shared_protocol import protocol_version
-from src.server.outbound_message import NodeType
-from src.server.server import ChiaServer, ssl_context_for_client
-from src.server.ws_connection import WSChiaConnection
-from src.ssl.create_ssl import generate_ca_signed_cert
-from src.types.blockchain_format.sized_bytes import bytes32
-from src.types.peer_info import PeerInfo
-from src.util.ints import uint16
+from chia.protocols.shared_protocol import protocol_version
+from chia.server.outbound_message import NodeType
+from chia.server.server import ChiaServer, ssl_context_for_client
+from chia.server.ws_connection import WSChiaConnection
+from chia.ssl.create_ssl import generate_ca_signed_cert
+from chia.types.blockchain_format.sized_bytes import bytes32
+from chia.types.peer_info import PeerInfo
+from chia.util.ints import uint16
 from tests.setup_nodes import self_hostname
 from tests.time_out_assert import time_out_assert
 
