@@ -51,8 +51,8 @@ class TestBlockStore:
                 await bc.receive_block(block)
                 block_record = bc.block_record(block.header_hash)
                 block_record_hh = block_record.header_hash
-                await store.add_full_block(block, block_record)
-                await store.add_full_block(block, block_record)
+                await store.add_full_block(block.header_hash, block, block_record)
+                await store.add_full_block(block.header_hash, block, block_record)
                 assert block == await store.get_full_block(block.header_hash)
                 assert block == await store.get_full_block(block.header_hash)
                 assert block_record == (await store.get_block_record(block_record_hh))
@@ -115,7 +115,11 @@ class TestBlockStore:
         for i in range(10000):
             rand_i = random.randint(0, 9)
             if random.random() < 0.5:
-                tasks.append(asyncio.create_task(store.add_full_block(blocks[rand_i], block_records[rand_i])))
+                tasks.append(
+                    asyncio.create_task(
+                        store.add_full_block(blocks[rand_i].header_hash, blocks[rand_i], block_records[rand_i])
+                    )
+                )
             if random.random() < 0.5:
                 tasks.append(asyncio.create_task(store.get_full_block(blocks[rand_i].header_hash)))
         await asyncio.gather(*tasks)
